<?php 
/**
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_team_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if team is enabled
        $enable_team = apply_filters( 'corporate_education_pro_section_status', true, 'team_enable' );

        if ( true !== $enable_team ) {
            return false;
        }

        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'corporate_education_pro_filter_team_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render team section now.
        corporate_education_pro_render_team_section( $section_details );
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_team_section', 70 );


if ( ! function_exists( 'corporate_education_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Corporate Education Pro 1.0
    * @param array $input team section details.
    */
    function corporate_education_pro_get_team_section_details( $input ) {
        $options = corporate_education_pro_get_theme_options();

        // team intro type
        $team_intro_content_type  = $options['team_intro_content_type'];

        $content = array();
        switch ( $team_intro_content_type ) {
          	case 'demo':
                $content['intro'][1]['title']    = esc_html__( 'Professional Teachers', 'corporate-education-pro' );
                $content['intro'][1]['url']      = '#';
                $content['intro'][1]['excerpt']  = esc_html__( 'Cras sit amet condimentum diam. Fusce enim ligula, pellentesque at imperdiet eget, condimentum id mi. Integer ac quam ut tellus egestas consequat. Duis ultrices quam vel feugiat hendrerit. Etiam tempor tempus mauris, vel pretium nunc bibendum id. Nam elementum pretium placerat.', 'corporate-education-pro' );
            break;  

            case 'custom':
                $content['intro'][1]['title']    = ! empty( $options['team_intro_title'] ) ? $options['team_intro_title'] : '';
                $content['intro'][1]['url']      = ! empty( $options['team_intro_btn_url'] ) ? $options['team_intro_btn_url'] : '';
                $content['intro'][1]['excerpt']  = ! empty( $options['team_intro_description'] ) ? $options['team_intro_description'] : '';
            break;        

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['team_intro_content_post'] ) )
                    $post_id = absint( $options['team_intro_content_post'] );

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }

                $content['intro'][1]['title']    = get_the_title( $post_id );
                $content['intro'][1]['url']      = get_the_permalink( $post_id );
                $content['intro'][1]['excerpt']  = corporate_education_pro_trim_content( 40 , get_post( $post_id ) );
                                            
          	break;

            case 'page':
                $page_id = '';
                
                if ( ! empty( $options['team_intro_content_page'] ) )
                    $page_id = absint( $options['team_intro_content_page'] );

                // Bail if no valid pages are selected.
                if ( empty( $page_id ) ) {
                    return $input;
                }

                $content['intro'][1]['title']    = get_the_title( $page_id );
                $content['intro'][1]['url']      = get_the_permalink( $page_id );
                $content['intro'][1]['excerpt']  = corporate_education_pro_trim_content( 40, get_post( $page_id ) );
                                            
            break;
        }

        // team type
        $team_content_type  = $options['team_content_type'];

        switch ( $team_content_type ) {
            case 'demo':
                $team_title = array(
                    1 => esc_html__( 'Ricky Ortega', 'corporate-education-pro' ),
                    2 => esc_html__( 'Anna Orcutt', 'corporate-education-pro' ),
                    3 => esc_html__( 'Linda Smith', 'corporate-education-pro' ),
                    4 => esc_html__( 'Nicole Hyat', 'corporate-education-pro' ),
                    5 => esc_html__( 'Peter Cann', 'corporate-education-pro' ),
                    6 => esc_html__( 'Sam Smith', 'corporate-education-pro' ),
                    );
                for ( $i = 1; $i <= 6; $i++ ) {
                    $content['team'][$i]['id']      = '';
                    $content['team'][$i]['title']   = $team_title[$i];
                    $content['team'][$i]['url']     = '#';
                    $content['team'][$i]['img_array'][0]    = get_template_directory_uri() . '/assets/uploads/team-0' . $i . '.jpg';
                    $content['team'][$i]['img_array'][1]    = 400;
                    $content['team'][$i]['img_array'][2]    = 400;
                }

            break; 

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['team_content_category'] ) ) {
                    $cat_id = $options['team_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 6,
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['team_content_post'] ) )
                    $ids = ( array ) $options['team_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );                             
            break;

            case 'team':
                $ids = array();
                
                if ( ! empty( $options['team_content_team'] ) )
                    $ids = ( array ) $options['team_content_team'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-team',
                    'post__in'       => $ids,
                    'posts_per_page' => 6,
                );                             
            break;

            case 'team-category':
                $cat_id = '';
                if ( ! empty( $options['team_content_team_category'] ) ) {
                    $cat_id = $options['team_content_team_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => 6,
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-team-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

        } 

        if ( 'demo' != $team_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = array();
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'corporate-education-pro-medium' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                        $img_array[1] =  500;
                        $img_array[2] =  500;
                    }

                    if ( isset( $img_array ) ) {
                        $content['team'][$i]['img_array'] = $img_array;
                    }
                    $content['team'][$i]['id']      = $post_id;
                    $content['team'][$i]['title']   = get_the_title( $post_id );
                    $content['team'][$i]['url']     = get_the_permalink( $post_id );
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'corporate_education_pro_filter_team_section_details', 'corporate_education_pro_get_team_section_details' );


if ( ! function_exists( 'corporate_education_pro_render_team_section' ) ) :
    /**
    * Start team section
    *
    * @return string team content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_team_section( $content_details ) {
        $options    = corporate_education_pro_get_theme_options();
        $team_content_type  = $options['team_content_type'];
        $team_sub_title  = ! empty( $options['team_intro_sub_title'] ) ? $options['team_intro_sub_title'] : '';
        $readmore   = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read More', 'corporate-education-pro' );
        $readmore   = ( 'custom' == $options['team_intro_content_type'] ) ? $options['team_intro_btn_label'] : $readmore;

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="team-members">
            <div class="gray-shape top move-up left"></div>
            <div class="blue-shape bottom move-down right"></div>

            <div class="team-section-wrapper col-2">
                <?php foreach ( $content_details['intro'] as $content_detail ) : ?>
                    <div class="hentry">
                        <div class="left-half page-section">
                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content_detail['title'] ); ?></h2>
                                <?php if ( ! empty( $team_sub_title ) ) : ?>
                                    <p class="entry-title-desc"><?php echo esc_html( $team_sub_title ); ?></p>
                                <?php endif; ?>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content_detail['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if ( ! empty( $content_detail['url'] ) ) : ?>
                                <div class="view-more">
                                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="btn btn-blue-transparent"><?php echo esc_html( $readmore ); ?></a>
                                </div><!-- .view-more -->
                            <?php endif; ?>
                        </div><!-- .left-half -->
                    </div><!-- .hentry -->
                <?php endforeach; ?>

                <div class="hentry">
                    <div class="right-half page-section">
                        <div class="staff-members-wrapper col-3 clear">
                            <?php foreach ( $content_details['team'] as $content_detail ) : ?>
                                <div class="staff">
                                    <div class="staff-detail-wrapper">
                                        <figure class="featured-image">
                                            <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content_detail['title'] ); ?>"></a>
                                        </figure>
                                        <div class="staff-details">
                                            <h5 class="staff-name"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                            <?php if ( in_array( $team_content_type, array( 'team', 'team-category' ) ) ) : 
                                                if ( has_action( 'tp_team_designation_action' ) ) :
                                                    do_action( 'tp_team_designation_action', $content_detail['id'] );
                                                endif;
                                            elseif ( $team_content_type == 'demo' ) : ?>
                                                <span class="tp-team-designation"><?php esc_html_e( 'Professor', 'corporate-education-pro' ); ?></span>
                                            <?php endif; ?>
                                        </div><!-- .staff-details -->
                                    </div><!-- .staff-detail-wrapper -->
                                </div><!-- .staff -->
                            <?php endforeach; ?>
                        </div><!-- .staff-members-wrapper -->
                    </div><!-- .right-half -->
                </div><!-- .hentry -->
            </div><!-- .team-section-wrapper -->
        </section><!-- #team-members -->
    <?php }
endif;
